/*!
 * © 2017 David Vines
 *
 * Creative Commons License
 *
 * This work is licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.
 */
/* globals Row, Club */
/* exported ClubRow, setupClubs */

function setupClubs(cid) {
}

function ClubRow(sl,regiment,oldClub) {
    Row.call(this);
    
    this._sl = sl;
    this._regiment = regiment;
    this._oldClub = oldClub;
}

ClubRow.prototype = Object.create(Row.prototype);

ClubRow.prototype.activate = function(cid) {
    Row.prototype.activate.call(this,cid);
    
    this._leave = document.getElementById(cid+"-club-leave");
    this._leaveLabel = document.getElementById(cid+"-club-leave-label");
    this._choice = document.getElementById(cid+"-club");
    this._choiceLabel = document.getElementById(cid+"-club-join-label");
   
    if (this._oldClub) {
        this._leaveLabel.textContent = "Leave "+this._oldClub.name;
    }
    
    this._choice.length = 1; // Keep the blank first entry
    this._noEligibleClub = true;
    var self = this;
    Club.forEach(function(club) {
        var option = document.createElement("option");
        option.text = club.name;
        if (club.meetsRequirement(self._regiment,self._sl)) {
            self._noEligibleClub = false;
        } else {
            option.disabled = true;
        }
        self._choice.add(option);
    });

    this.disableOnFlag(this._noEligibleClub,this._choice,this._choiceLabel);
    
    this.controlledBy(this._leave);
    this.controlledBy(this._choice);
    
    this.addInnerHTML(document.getElementById(cid+"-club-effect"));
    this.addOrderField(document.getElementById(cid+"-form-club"));
    this.addNotesField(document.getElementById(cid+"-form-club-effect"));
    
    this.processChange();
};

ClubRow.prototype.processChange = function() {
    var club = (this._leave.checked ? null : this._oldClub);
    var order = "";
    var notes = ""; // Default text
    if (this._leave.checked && this._oldClub) {
        order = "Leave "+this._oldClub.name;
    }
    if (this._choice.selectedIndex > 0) {
        club = Club.forName(this._choice.options[this._choice.selectedIndex].text);
        order += (order === "" ? "" : " and ") + "Join "+club.name+".";
        if (club.meetsRequirement(this._regiment,this._sl)) {
            notes = "Joined "+club.name+". ";
        } else {
            notes = club.failsRequirement(this._regiment,this._sl);
            club = null;
        }
    }
    if (this._inParis.checked && club) {
        notes += "Dues of "+club.dues+" Crowns. Gain "+club.sp+" Status Points.";
    } else if (!this._inParis.checked) {
        notes += "Cannot change club while out of Paris (no club fees will be levied however).";
    } else if (this._noEligibleClub) {
        notes += "Sadly no club will accept one with your low social level as a member.";
    }
    if (order === "") {
        order = "No Change"; 
    }
    
    // enable/disable fields as appropriate
    if (this._inParis.checked) {
        this.enableOnFlag(this._oldClub,this._leave,this._leaveLabel);
        if (this._oldClub) {
            this.disableOnFlag(!this._leave.checked,this._choice,this._choiceLabel);
        } else {
            this.enable(this._choice,this._choiceLabel);
        }
    } else {
        this.disable(this._leave,this._leaveLabel);
        this.disable(this._choice,this._choiceLabel);
    }

    this.notifyOrder(order);
    this.notifyCommentary(notes);
};
