/*!
 * © 2017 David Vines
 *
 * Creative Commons License
 *
 * This work is licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.
 */
/* globals Row */
/* exported DuelRow */

function DuelRow(weekno,sl,endurance,who,notes,rapier,sabre,cutlass) {
    Row.call(this);
    
    if (notes) {
        notes = (notes+",,").split(','); // ,, to ensure we do split the string into at least three pieces
    } else {
        notes = ["","",""];
    }
    
    this._weekno = weekno;
    this._sl = sl;
    this._endurance = endurance;
    this._who = who;
    this._role = notes[0];
    this._win = notes[1];
    this._lose = notes[2];
    this._rapier = rapier;
    this._sabre = sabre;
    this._cutlass = cutlass;
}

DuelRow.prototype = Object.create(Row.prototype);

/* jshint noempty: false */
DuelRow.prototype.activate = function(cid) {
    Row.prototype.activate.call(this,cid);
    
    this._prefix = cid+"-week-"+this._weekno+"-duel";
    this._duel = document.getElementById(this._prefix);

    if (this._who) {
        this._accept = document.getElementById(this._prefix+"-accept");
        this._acceptLabel = document.getElementById(this._prefix+"-accept-label");
        this._details = document.getElementById(this._prefix+"-details");
        this._rapierButton = document.getElementById(this._prefix+"-weapon-choice-rapier");
        this._sabreButton = document.getElementById(this._prefix+"-weapon-choice-sabre");
        this._cutlassButton = document.getElementById(this._prefix+"-weapon-choice-cutlass");
        this._chosen = document.getElementById(this._prefix+"-weapon-chosen");
        this._attack = document.getElementById(this._prefix+"-attack");
        this._attackText= document.getElementById(this._prefix+"-attack-description");
        this._offerSurrender = document.getElementById(this._prefix+"-offer-surrender");
        this._acceptSurrender = document.getElementById(this._prefix+"-accept-surrender");
        
        if (this._role !== "Protagonist") {
            document.getElementById(this._prefix+"-state").textContent = "are due to fight "+this._who+" at the start of this week";
        } else {
            document.getElementById(this._prefix+"-state").textContent = "have been challenged to a duel at the start of this week by "+this._who;
        }
        
        var self = this;
        this._rapierButton.onchange = function() {
            self.processWeaponChange();
        };
        document.getElementById(this._prefix+"-attack-decrease").onclick = function() {
            var newvalue = self._attack.valueAsNumber-1;
            if (newvalue >= self._attack.min) {
                self._attack.value = newvalue;
                self.processChange();
            }
        };
        document.getElementById(this._prefix+"-attack-increase").onclick = function() {
            var newvalue = self._attack.valueAsNumber+1;
            if (newvalue <= self._attack.max) {
                self._attack.value = newvalue;
                self.processChange();
            }
        };
        this._sabreButton.onchange = this._rapierButton.onchange;
        this._cutlassButton.onchange = this._rapierButton.onchange;
        this.processWeaponChange();
        
        this.controlledBy(this._accept);
        this.controlledBy(this._attack);
        this.controlledBy(this._offerSurrender);
        this.controlledBy(this._acceptSurrender);
    } else {
        this.hide(this._duel);
    }
    
    this.addInnerHTML(document.getElementById(this._prefix+"-effect"));
    this.addOrderField(document.getElementById(cid+"-form-week"+this._weekno+"-duel"));
    this.addDetailsField(document.getElementById(cid+"-form-week"+this._weekno+"-duel-notes"));
    this.addNotesField(document.getElementById(cid+"-form-week"+this._weekno+"-duel-effect"));

    this.processChange();
};

DuelRow.prototype.processWeaponChange = function() {
    var options = "";
    var weapon = "rapier";
    var skill = this._rapier;
    
    if (this._sabreButton.checked) {
        weapon = "sabre"; skill = this._sabre;
    } else if (this._cutlassButton.checked) {
        weapon = "cutlass"; skill = this._cutlass;
    }
    
    this._chosen.textContent = weapon;
    this._attack.max = skill;
    if (this._attack.value > this._attack.max) {
        this._attack.value = this._attack.max;
    }

    for(var i=this._attack.min; i<=this._attack.max; i++) {
        options += '<option value="'+i+'"/>';
    }
    document.getElementById(this._prefix+"-attack-tickmarks").innerHTML = options;
    
    this.processChange();
};

DuelRow.prototype.processChange = function() {
    var order = "";
    var notes = ""; // Default text
    
    if (this._who) {
        if (this._inParis.checked) {
            var currentEndurance = Number(this._endurance.split(' of ')[0]);
            var maximumEndurance = Number(this._endurance.split(' of ')[1]);
            var healthy = true;
            
            if (currentEndurance < maximumEndurance/2) {
                notes = "As you are seriously wounded (under half of maximum endurance) you will not lose any status points if you refuse to fight this duel. ";
                healthy = false;
            }
    
            if (this._accept.checked) {
                this.show(this._details);
                
                var weapon = "rapier";
                var skill = this._rapier;
                if (this._sabreButton.checked) {
                    weapon = "sabre"; skill = this._sabre;
                } else if (this._cutlassButton.checked) {
                    weapon = "cutlass"; skill = this._cutlass;
                }
                
                notes += "If you win the duel, you will gain "+this._win+" status points and gain one expertise in "+weapon+". ";
                if (this._lose > 0) {
                    notes += "If, on the other hand, you lose the duel, you will lose "+this._lose+" status points. ";
                }
                notes += "If you kill your opponent you will gain an additional two status points. ";
                    
                this._attackText.textContent = this._attack.value+" Attack, "+(skill-this._attack.value)+" Defence";
                
                order =  "Fight with "+weapon+" ("+this._attackText.textContent+").";
                order += " Offer surrender "+this._offerSurrender.options[this._offerSurrender.selectedIndex].value;
                order += ", Accept surrender "+this._acceptSurrender.options[this._acceptSurrender.selectedIndex].value;
                order += ".";
            } else {
                this.hide(this._details);
                if (healthy) {
                    notes += "Lose "+Math.floor(this._sl/2)+" status points for not fighting the scheduled duel. ";
                }
            }
        } else {
            // Scheduled to fight, but out of paris
            this._accept.checked = false;
            this.disable(this._accept,this._acceptLabel);
            this.hide(this._details);
            order = "Out of Paris, duel posponed.";
            notes = "As you are out of paris, the duel is posponed until your return.";
        }
    }
    
    this.notifyOrder(order);
    this.notifyCommentary(notes);
};
